# Changelog

<!--next-version-placeholder-->

## v0.14.4 (2023-11-11)

### Fix

* Missing f-string ([`fa75e8a`](https://github.com/Smithed-MC/smithed-python/commit/fa75e8a170c426868308f711d1b7a65e409ea624))

## v0.14.3 (2023-11-11)

### Fix

* Improve debugging ([`1cf4808`](https://github.com/Smithed-MC/smithed-python/commit/1cf480884547e66f56475057764ff047e329c0aa))

### Documentation

* Fixup changelog ([`8239620`](https://github.com/Smithed-MC/smithed-python/commit/8239620990dd25a890edee227262ba2b812416a8))

## v0.14.2 (2023-10-15)

### Fix

* display error better + bump beet ver ([`604ad54`](https://github.com/Smithed-MC/smithed-python/tree/604ad549fd0ae25df6c231f833fda183b6acf4e2))

## v0.14.1 (2023-10-12)

### Fix

* Temporarily remove unknown_files plugin ([`6451071`](https://github.com/Smithed-MC/smithed-python/commit/6451071cffffc64c8891341a76f0ef820edc359b))

## v0.14.0 (2023-10-12)

### Feature

* Add overlays support and speedup for webapp ([`d56f3e1`](https://github.com/Smithed-MC/smithed-python/commit/d56f3e14d46599f09edfad13c79066f391e12770))

## v0.13.4 (2023-10-12)

### Fix

* Merge conflict ([`9c53472`](https://github.com/Smithed-MC/smithed-python/commit/9c5347260062fa2cb8d5675b4c370463f2b311ea))

## v0.13.3 (2023-09-03)

### Fix

* Remove 2 pack for weld, make loading packs better ([`552db97`](https://github.com/Smithed-MC/smithed-python/commit/552db97d427aea9b252db5b2235773b84c5d904b))

## v0.13.2 (2023-08-31)

### Fix

* Adjust dependencies ([`06aa745`](https://github.com/Smithed-MC/smithed-python/commit/06aa745f5963d7b0681cef9a87a2e047980bcdf8))

## v0.13.1 (2023-08-31)

### Fix

* Patch __init__.py ([`7d3b0ad`](https://github.com/Smithed-MC/smithed-python/commit/7d3b0ad4d5b6c8b959ced05a7ad2a547e6df1a73))

## v0.13.0 (2023-08-31)

### Feature

* Neat icon there ([`3129f2b`](https://github.com/Smithed-MC/smithed-python/commit/3129f2bd52e8b7159a268eb7393a4fa5406b9867))
* Add override as a way to completely take over the file ([`4e86277`](https://github.com/Smithed-MC/smithed-python/commit/4e8627737b95bd789ce2ab5927de04cabcbe85cd))
* Add conditions, tests for stages and conditions ([`5d5ba28`](https://github.com/Smithed-MC/smithed-python/commit/5d5ba28e0f3559ab059e552355e871d6518ecc0f))
* Cli working, tests, and more ([`9dc9374`](https://github.com/Smithed-MC/smithed-python/commit/9dc9374867f3b017ea31a73ea7f0c38b50c2392c))
* Fix up weld cli and more ([`eef7bba`](https://github.com/Smithed-MC/smithed-python/commit/eef7bbaee659e839990a6154900e78f2280f3c7c))
* But good ([`3f0ec52`](https://github.com/Smithed-MC/smithed-python/commit/3f0ec52d1b6559ecf57e057cdcbf629ca5dcad31))

### Fix

* Tests, streamlit, etc ([`0d166fb`](https://github.com/Smithed-MC/smithed-python/commit/0d166fbb6a76d8154c9553b08f4054b72a1ee12f))
* Update streamlit to newest weld ([`be54f60`](https://github.com/Smithed-MC/smithed-python/commit/be54f60d277078ae446194f5264ae4cd3809bc96))
* Use backport strenum for 3.10 ([`a2adbbe`](https://github.com/Smithed-MC/smithed-python/commit/a2adbbe266394265c5e1c2aa4bb0db6170fc22ea))
* Secure rules, add tests ([`1f8f0ef`](https://github.com/Smithed-MC/smithed-python/commit/1f8f0efe41d038bf478bb1221618cbfc0f60871b))

## v0.12.0 (2023-07-07)
### Feature
* Add manual streamlit option `streamlit run app/main.py` ([`6fc26f9`](https://github.com/Smithed-MC/smithed-python/commit/6fc26f9d301018312d0dc3f7695a9f558c70ba27))

### Fix
* Bump ver ([`e19f1d5`](https://github.com/Smithed-MC/smithed-python/commit/e19f1d564b085379cee7b64f65e428ecd3f960ef))

## v0.11.2 (2023-06-13)
### Fix
* Update deps, include explicit model merging ([`2312515`](https://github.com/Smithed-MC/smithed-python/commit/23125157be27cadc6a335c21a9379d9cab99e1f0))
* Update stlite to latest ([`f8b2d1a`](https://github.com/Smithed-MC/smithed-python/commit/f8b2d1a19a13ccfa935711fd1a22d7ea8a6be95d))
* Add altair as weld app dep ([`ef2bf45`](https://github.com/Smithed-MC/smithed-python/commit/ef2bf45500c630f6e9805d999f2c0f1a4f8ed6d9))

## v0.11.1 (2023-04-25)
### Fix
* Bump mecha, bolt ([`44adc8b`](https://github.com/Smithed-MC/smithed-python/commit/44adc8b5c58fd147abd4011154c28a93dae9688d))

## v0.11.0 (2023-04-25)
### Feature
* Upgrade `beet` and add `unknown_files` plugin ([`8ceb8c6`](https://github.com/Smithed-MC/smithed-python/commit/8ceb8c6db2ad3828e0a86c2c14490639bfc21ae0))

## v0.10.0 (2023-04-24)
### Feature
* Adjust for newest snapshot ([`d4778de`](https://github.com/Smithed-MC/smithed-python/commit/d4778de31526f6b4f56bbe3818ae9362bbf8dac9))

## v0.9.3 (2023-03-27)
### Fix
* Force release ([`1829d6d`](https://github.com/Smithed-MC/smithed-python/commit/1829d6dd2cd0d43aadfafcad7aeca2cace64f981))
* Disable tests for now on CI ([`24bbd16`](https://github.com/Smithed-MC/smithed-python/commit/24bbd1648690927c5bf3a05d5e5f1b18f85dff07))
* Full test verbosity ([`80c1293`](https://github.com/Smithed-MC/smithed-python/commit/80c1293a71d41ad54ef6ffb3dcddba845ae2d437))
* Update beet and deps + add github action ([`11ab749`](https://github.com/Smithed-MC/smithed-python/commit/11ab7493166b8c5fa92574466d89e3aec9cc60af))

## v0.9.2 (2023-02-15)
### Fix
* Disable latest snapshot if it fails ([`c72432f`](https://github.com/Smithed-MC/smithed-python/commit/c72432fcf83e0cf3aa4beb55356bdbeb21cda823))

## v0.9.1 (2023-02-01)


## v0.9.0 (2023-02-01)
### Fix
* Add versioning to weld ([`8372224`](https://github.com/Smithed-MC/smithed-python/commit/8372224d38a74d13c99027c49910d2051997c15d))
* Use correct package ([`a82f18c`](https://github.com/Smithed-MC/smithed-python/commit/a82f18cb57aaf9c3807e5fc8dcd47fad61f511ce))

## v0.8.0 (2023-02-01)
### Feature
* Add atlas support ([`35355f3`](https://github.com/Smithed-MC/smithed-python/commit/35355f314162991ee1584ba0279c7ad3b8174e1e))

## v0.7.2 (2023-01-09)
### Fix
* App not reloading ([`16c1b4d`](https://github.com/Smithed-MC/smithed-python/commit/16c1b4d660cb68fd3397e79c9f67ea89623585b0))
* Mistake with app/index.html ([`69e9a92`](https://github.com/Smithed-MC/smithed-python/commit/69e9a92b0710a2ad4cfb466e514ebe9f30eb155a))

## v0.7.1 (2023-01-09)


## v0.7.0 (2023-01-09)
### Feature
* Move app source to `weld` package ([`f59da76`](https://github.com/Smithed-MC/smithed-python/commit/f59da7613ac2c89e72753152e82edcd853097eb5))

## v0.6.1 (2023-01-09)


## v0.6.0 (2023-01-09)
### Feature
* Fix bug ([`c27732a`](https://github.com/Smithed-MC/smithed-python/commit/c27732a84d02a720ad34ee3decc2cfe189b7f322))

## v0.5.0 (2023-01-09)
### Feature
* Implement experiemental fabric output feature ([`403052e`](https://github.com/Smithed-MC/smithed-python/commit/403052ee8669de9c1503d4e6e64f7e86caee59cc))
* Add experimental fabric jar download ([`d23846c`](https://github.com/Smithed-MC/smithed-python/commit/d23846cebf6583dd4a5ee6f559b515a7fd6976d0))
* Improve app to use smithed and intents ([`6e17188`](https://github.com/Smithed-MC/smithed-python/commit/6e171880f969bede7846d72ecab181c574782cf9))

### Fix
* Hosted app ([`9dce4a8`](https://github.com/Smithed-MC/smithed-python/commit/9dce4a893da3598496c269eda3d59cda7b893ddb))

## v0.4.0 (2023-01-08)


## v0.3.0 (2023-01-08)
### Feature
* Redid everything ([`92dc2db`](https://github.com/Smithed-MC/smithed-python/commit/92dc2db7f98598246addb8f33cbed6754eb96fea))

## v0.2.0 (2022-12-13)
### Feature
* **weld:** First version of weld ([`6a9d2bd`](https://github.com/Smithed-MC/smithed-python/commit/6a9d2bd09bc35655da6a475bd9d0464aec1a9260))
